#!/usr/bin/env python2
# -*- coding: utf-8 -*-

from distutils.core import setup

setup(
    name='gogo',
    version='1.0.2',
    description='Golang package navigator',
    author='Viet Hung Nguyen',
    author_email='hvn@familug.org',
    url='https://github.com/hvnsweeting/gogo',
    scripts=['gogo'],
)
